@@ -28,7 +28,7 @@ import java.util.*;
  * {@link ts.util.file.FileOperation06Move FileOperation06Move}NX̋@\NXB
  *
  * @author  V.
- * @version $Revision: 1.2 $, $Date: 2007/05/27 16:13:11 $
+ * @version $Revision: 1.3 $, $Date: 2007/10/09 16:57:13 $
  */
 public class FileOperation06MoveTest extends FunctionTester
 {
@@ -805,6 +805,34 @@ public class FileOperation06MoveTest extends FunctionTester
     }
   }
 
+  public void move_withFilter011()
+  {
+    MSG("ړ̃t@C̐efBNg݂ȂƂɃG[ƂȂꍇB");
+
+    @SuppressWarnings("serial")
+    File src = new File(FILES[1].getPath()) {
+      public boolean renameTo(File f) { return false; }
+    };
+    File dst = new File(WORKDIR, "bbb/ccc/ddd");
+
+    FileFilter filter = new FileTypeFilter(FileType.File);
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+    FALSE(dst.getParentFile().exists());
+
+    try {
+      FileOperation.move(src, dst, filter);
+      NG();
+    } catch (IOException e) {
+      OK(e);
+    }
+
+    TRUE(src.exists());
+    FALSE(dst.exists());
+    FALSE(dst.getParentFile().exists());
+  }
+
   public void moveRecursive()
   {
     MSG("łȂfBNgړꍇB");
